githack

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2023 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var GithackCmd = &cobra.Command{
	Use:   "githack",
	Short: "A `.git` folder disclosure exploit",
	Long:  `A Git source leak exploit tool that restores the entire Git repository, including data from stash, for white-box auditing and analysis of developers' mind`,
	Args: func(cmd *cobra.Command, args []string) (err error) {
		if len(args) < 1 {
			return errors.New("requires a url argument")
		}
		if err = validator.New().Var(args[0], "url"); err != nil {
			return
		}
		if !strings.HasPrefix(args[0], "http") {
			return errors.New("must be http(s)")
		}
		return nil
	},
	RunE: func(cmd *cobra.Command, args []string) error {
		if delay > 0 {
			limit = 1
		}
		return gitHack(args[0], limit, delay)
	},
}

Functions

func ExportCommand

func ExportCommand() []*cobra.Command

Types

This section is empty.

Jump to