Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var GithackCmd = &cobra.Command{ Use: "githack", Short: "A `.git` folder disclosure exploit", Long: `A Git source leak exploit tool that restores the entire Git repository, including data from stash, for white-box auditing and analysis of developers' mind`, Args: func(cmd *cobra.Command, args []string) (err error) { if len(args) < 1 { return errors.New("requires a url argument") } if err = validator.New().Var(args[0], "url"); err != nil { return } if !strings.HasPrefix(args[0], "http") { return errors.New("must be http(s)") } return nil }, RunE: func(cmd *cobra.Command, args []string) error { if delay > 0 { limit = 1 } return gitHack(args[0], limit, delay) }, }
Functions ¶
func ExportCommand ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.